==> dojo-1.9.2-javadoc.jar: dojo/cldr/nls/de/hebrew.js.uncompressed.js <==
define(
"dojo/cldr/nls/de/hebrew", //begin v1.x content
{
	"field-dayperiod": "Tageshälfte",
	"dateFormatItem-yyyyMMMEd": "E, d. MMM y G",
	"dayPeriods-format-wide-pm": "nachm.",
	"field-minute": "Minute",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"field-day-relative+-1": "Gestern",
	"field-weekday": "Wochentag",
	"field-day-relative+-2": "Vorgestern",
	"days-standAlone-wide": [
		"Sonntag",
		"Montag",
		"Dienstag",
		"Mittwoch",
		"Donnerstag",
		"Freitag",
		"Samstag"
	],
	"field-era": "Epoche",
	"dateFormatItem-Gy": "y G",
	"field-hour": "Stunde",
	"dayPeriods-format-wide-am": "vorm.",
	"dateFormatItem-y": "y G",
	"dateFormatItem-yyyy": "y G",
	"dateFormatItem-Ed": "E, d.",
	"field-day-relative+0": "Heute",
	"field-day-relative+1": "Morgen",
	"days-standAlone-narrow": [
		"S",
		"M",
		"D",
		"M",
		"D",
		"F",
		"S"
	],
	"eraAbbr": [
		"AM"
	],
	"field-day-relative+2": "Übermorgen",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"dateFormat-long": "d. MMMM y G",
	"field-zone": "Zone",
	"field-week-relative+-1": "Letzte Woche",
	"dateFormat-medium": "dd.MM.y G",
	"field-year-relative+0": "Dieses Jahr",
	"field-year-relative+1": "Nächstes Jahr",
	"quarters-standAlone-wide": [
		"1. Quartal",
		"2. Quartal",
		"3. Quartal",
		"4. Quartal"
	],
	"field-year-relative+-1": "Letztes Jahr",
	"field-year": "Jahr",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-week": "Woche",
	"dateFormatItem-yyyyMd": "d.M.y GGGGG",
	"dateFormatItem-yyyyMMMd": "d. MMM y G",
	"dateFormatItem-yyyyMEd": "E, d.M.y GGGGG",
	"dateFormatItem-MMMd": "d. MMM",
	"field-week-relative+0": "Diese Woche",
	"field-week-relative+1": "Nächste Woche",
	"field-month-relative+0": "Dieser Monat",
	"field-month": "Monat",
	"field-month-relative+1": "Nächster Monat",
	"dateFormatItem-H": "HH 'Uhr'",
	"days-format-abbr": [
		"So.",
		"Mo.",
		"Di.",
		"Mi.",
		"Do.",
		"Fr.",
		"Sa."
	],
	"days-format-narrow": [
		"S",
		"M",
		"D",
		"M",
		"D",
		"F",
		"S"
	],
	"field-second": "Sekunde",
	"dateFormatItem-GyMMMEd": "E, d. MMM y G",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-day": "Tag",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dateFormatItem-MEd": "E, d.M.",
	"days-standAlone-short": [
		"So.",
		"Mo.",
		"Di.",
		"Mi.",
		"Do.",
		"Fr.",
		"Sa."
	],
	"days-standAlone-abbr": [
		"So",
		"Mo",
		"Di",
		"Mi",
		"Do",
		"Fr",
		"Sa"
	],
	"dateFormat-short": "dd.MM.yy GGGGG",
	"dateFormatItem-yyyyM": "M.y GGGGG",
	"dateFormatItem-Md": "d.M.",
	"dateFormat-full": "EEEE, d. MMMM y G",
	"days-format-short": [
		"So.",
		"Mo.",
		"Di.",
		"Mi.",
		"Do.",
		"Fr.",
		"Sa."
	],
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-month-relative+-1": "Letzter Monat",
	"quarters-format-wide": [
		"1. Quartal",
		"2. Quartal",
		"3. Quartal",
		"4. Quartal"
	],
	"days-format-wide": [
		"Sonntag",
		"Montag",
		"Dienstag",
		"Mittwoch",
		"Donnerstag",
		"Freitag",
		"Samstag"
	]
}
//end v1.x content
);

==> dojo-1.10.1-javadoc.jar: dojo/cldr/nls/de/hebrew.js.uncompressed.js <==
define(
"dojo/cldr/nls/de/hebrew", //begin v1.x content
{
	"days-standAlone-short": [
		"So.",
		"Mo.",
		"Di.",
		"Mi.",
		"Do.",
		"Fr.",
		"Sa."
	],
	"field-second-relative+0": "jetzt",
	"field-weekday": "Wochentag",
	"field-wed-relative+0": "Diesen Mittwoch",
	"field-wed-relative+1": "Nächsten Mittwoch",
	"dateFormatItem-GyMMMEd": "E, d. MMM y G",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"field-tue-relative+-1": "Letzten Dienstag",
	"days-format-short": [
		"So.",
		"Mo.",
		"Di.",
		"Mi.",
		"Do.",
		"Fr.",
		"Sa."
	],
	"dateFormat-long": "d. MMMM y G",
	"field-fri-relative+-1": "Letzten Freitag",
	"field-wed-relative+-1": "Letzten Mittwoch",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dayPeriods-format-wide-pm": "nachm.",
	"dateFormat-full": "EEEE, d. MMMM y G",
	"dateFormatItem-yyyyMEd": "E, d.M.y GGGGG",
	"field-thu-relative+-1": "Letzten Donnerstag",
	"dateFormatItem-Md": "d.M.",
	"dayPeriods-format-wide-noon": "Mittag",
	"field-era": "Epoche",
	"quarters-format-wide": [
		"1. Quartal",
		"2. Quartal",
		"3. Quartal",
		"4. Quartal"
	],
	"field-year": "Jahr",
	"field-hour": "Stunde",
	"field-sat-relative+0": "Diesen Samstag",
	"field-sat-relative+1": "Nächsten Samstag",
	"field-day-relative+0": "Heute",
	"field-thu-relative+0": "Diesen Donnerstag",
	"field-day-relative+1": "Morgen",
	"field-thu-relative+1": "Nächsten Donnerstag",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"field-day-relative+2": "Übermorgen",
	"dateFormatItem-H": "HH 'Uhr'",
	"quarters-standAlone-wide": [
		"1. Quartal",
		"2. Quartal",
		"3. Quartal",
		"4. Quartal"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E, d. MMM y G",
	"days-standAlone-wide": [
		"Sonntag",
		"Montag",
		"Dienstag",
		"Mittwoch",
		"Donnerstag",
		"Freitag",
		"Samstag"
	],
	"dateFormatItem-yyyyMMM": "MMM y G",
	"dateFormatItem-yyyyMMMd": "d. MMM y G",
	"field-sun-relative+0": "Diesen Sonntag",
	"field-sun-relative+1": "Nächsten Sonntag",
	"eraAbbr": [
		"AM"
	],
	"field-minute": "Minute",
	"field-dayperiod": "Tageshälfte",
	"days-standAlone-abbr": [
		"So",
		"Mo",
		"Di",
		"Mi",
		"Do",
		"Fr",
		"Sa"
	],
	"field-day-relative+-1": "Gestern",
	"field-day-relative+-2": "Vorgestern",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MEd": "E, d.M.",
	"field-fri-relative+0": "Diesen Freitag",
	"field-fri-relative+1": "Nächsten Freitag",
	"field-day": "Tag",
	"days-format-wide": [
		"Sonntag",
		"Montag",
		"Dienstag",
		"Mittwoch",
		"Donnerstag",
		"Freitag",
		"Samstag"
	],
	"field-zone": "Zeitzone",
	"dateFormatItem-y": "y G",
	"field-year-relative+-1": "Letztes Jahr",
	"field-month-relative+-1": "Letzter Monat",
	"days-format-abbr": [
		"So.",
		"Mo.",
		"Di.",
		"Mi.",
		"Do.",
		"Fr.",
		"Sa."
	],
	"days-format-narrow": [
		"S",
		"M",
		"D",
		"M",
		"D",
		"F",
		"S"
	],
	"dateFormatItem-yyyyMd": "d.M.y GGGGG",
	"field-month": "Monat",
	"days-standAlone-narrow": [
		"S",
		"M",
		"D",
		"M",
		"D",
		"F",
		"S"
	],
	"field-tue-relative+0": "Diesen Dienstag",
	"field-tue-relative+1": "Nächsten Dienstag",
	"dayPeriods-format-wide-am": "vorm.",
	"field-mon-relative+0": "Diesen Montag",
	"field-mon-relative+1": "Nächsten Montag",
	"dateFormat-short": "dd.MM.yy GGGGG",
	"field-second": "Sekunde",
	"field-sat-relative+-1": "Letzten Samstag",
	"field-sun-relative+-1": "Letzten Sonntag",
	"field-month-relative+0": "Dieser Monat",
	"field-month-relative+1": "Nächster Monat",
	"dateFormatItem-Ed": "E, d.",
	"field-week": "Woche",
	"dateFormat-medium": "dd.MM.y G",
	"field-year-relative+0": "Dieses Jahr",
	"field-week-relative+-1": "Letzte Woche",
	"dateFormatItem-yyyyM": "M.y GGGGG",
	"field-year-relative+1": "Nächstes Jahr",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "Letzten Montag",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "Diese Woche",
	"field-week-relative+1": "Nächste Woche"
}
//end v1.x content
);
